# Changelog

## [0.2.1](https://github.com/g4bri3lDev/py-jura/compare/v0.2.0...v0.2.1) (2026-03-05)


### Bug Fixes

* update jura manufacturer id ([a9a075a](https://github.com/g4bri3lDev/py-jura/commit/a9a075a2decd57f5448f183d71ea1e400c08b942))

## [0.2.0](https://github.com/g4bri3lDev/py-jura/compare/v0.1.1...v0.2.0) (2026-03-05)


### Features

* add methods to create JuraMachine from BLE device and parse advertisement data ([6ca3298](https://github.com/g4bri3lDev/py-jura/commit/6ca3298e6063a43a51bf65963bb6d46f9e72b640))

## [0.1.1](https://github.com/g4bri3lDev/py-jura/compare/v0.1.0...v0.1.1) (2026-03-05)


### Documentation

* update URLs ([82648a8](https://github.com/g4bri3lDev/py-jura/commit/82648a8e66150d5a45fe63777382179113fcbb05))

## 0.1.0 (2026-03-05)


### ⚠ BREAKING CHANGES

* initial implementation

### Features

* initial implementation ([99611f4](https://github.com/g4bri3lDev/py-jura/commit/99611f445b380bb89862c7b352b8e281510f5ed6))
